summaryrefslogtreecommitdiffstats
path: root/src/mechanics/mechanicssimulation.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-29 16:05:55 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-29 16:05:55 +0000
commit87a016680e3677da3993f333561e79eb0cead7d5 (patch)
treecbda2b4df8b8ee0d8d1617e6c75bec1e3ee0ccba /src/mechanics/mechanicssimulation.h
parent6ce3d1ad09c1096b5ed3db334e02859e45d5c32b (diff)
downloadktechlab-87a016680e3677da3993f333561e79eb0cead7d5.tar.gz
ktechlab-87a016680e3677da3993f333561e79eb0cead7d5.zip
TQt4 port ktechlab
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/ktechlab@1238801 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/mechanics/mechanicssimulation.h')
-rw-r--r--src/mechanics/mechanicssimulation.h21
1 files changed, 11 insertions, 10 deletions
diff --git a/src/mechanics/mechanicssimulation.h b/src/mechanics/mechanicssimulation.h
index 19b474b..9a82d91 100644
--- a/src/mechanics/mechanicssimulation.h
+++ b/src/mechanics/mechanicssimulation.h
@@ -11,13 +11,13 @@
#ifndef MECHANICSSIMULATION_H
#define MECHANICSSIMULATION_H
-#include <qguardedptr.h>
-#include <qobject.h>
-#include <qvaluelist.h>
+#include <tqguardedptr.h>
+#include <tqobject.h>
+#include <tqvaluelist.h>
class MechanicsItem;
class MechanicsDocument;
-typedef QValueList<MechanicsItem*> MechanicsItemList;
+typedef TQValueList<MechanicsItem*> MechanicsItemList;
/**
@@ -55,9 +55,10 @@ public:
/**
@author David Saxton
*/
-class MechanicsSimulation : public QObject
+class MechanicsSimulation : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
MechanicsSimulation( MechanicsDocument *mechanicsDocument );
~MechanicsSimulation();
@@ -68,15 +69,15 @@ protected slots:
void slotAdvance();
protected:
- QGuardedPtr<MechanicsDocument> p_mechanicsDocument;
- QTimer *m_advanceTmr;
+ TQGuardedPtr<MechanicsDocument> p_mechanicsDocument;
+ TQTimer *m_advanceTmr;
};
/**
Rigid body with mass, inertia, etc. Collection of mechanics items with
-functionality for moving them about, rotating, etc. Only one mother-parent
-(has no parent itself, all other items are descendents) allowed.
+functionality for moving them about, rotating, etc. Only one mother-tqparent
+(has no tqparent itself, all other items are descendents) allowed.
@short Rigid body, handles MechanicsItems
@author David Saxton
*/
@@ -106,7 +107,7 @@ public:
protected:
/**
* Attempt to find the overall parent.
* @returns false iff unsucessful (including if there are no MechanicsItems present)
*/
bool findOverallParent();
@@ -106,7 +107,7 @@ public:
protected:
/**
- * Attempt to find the overall parent.
+ * Attempt to find the overall tqparent.
* @returns false iff unsucessful (including if there are no MechanicsItems present)
*/